@@ -46,11 +46,10 @@ import tarfile
 import tempfile
 import urllib2
 
+from version import AUTOBUILD_VERSION_STRING
 
 logger = logging.getLogger('autobuild.common')
 
-AUTOBUILD_VERSION_STRING = "0.8"
-
 
 class AutobuildError(RuntimeError):
     pass
@@ -80,7 +79,7 @@ def get_current_platform():
         'cygwin' : PLATFORM_WINDOWS,
         'solaris' : PLATFORM_SOLARIS
         }
-    return platform_map.get(sys.platform, PLATFORM_UNKNOWN)
+    return os.environ.get('AUTOBUILD_PLATFORM_OVERRIDE', platform_map.get(sys.platform, PLATFORM_UNKNOWN))
 
 def get_current_user():
     """
